@@ -13,6 +13,7 @@ from .api_types import (
     BotDescription,
     BotName,
     BotShortDescription,
+    CallbackQueryId,
     Chat,
     ChatAdministratorRights,
     ChatId,
@@ -21,9 +22,11 @@ from .api_types import (
     ChatPermissions,
     File,
     FileId,
+    FirstName,
     ForumTopic,
     GameHighScore,
     InlineKeyboardMarkup,
+    InlineQueryId,
     InlineQueryResult,
     InlineQueryResultsButton,
     InputFile,
@@ -35,6 +38,7 @@ from .api_types import (
     InputMediaWithThumbnail,
     InputSticker,
     LabeledPrice,
+    LastName,
     LinkPreviewOptions,
     MaskPosition,
     MenuButton,
@@ -828,9 +832,9 @@ class ApiMethods(ABC):
         self,
         chat_id: ChatId | str,
         phone_number: str,
-        first_name: str,
+        first_name: FirstName,
         message_thread_id: MessageThreadId | None = None,
-        last_name: str | None = None,
+        last_name: LastName | None = None,
         vcard: str | None = None,
         disable_notification: bool | None = None,
         protect_content: bool | None = None,
@@ -1749,7 +1753,7 @@ class ApiMethods(ABC):
 
     async def answer_callback_query(
         self,
-        callback_query_id: str,
+        callback_query_id: CallbackQueryId,
         text: str | None = None,
         show_alert: bool | None = None,
         url: str | None = None,
@@ -2530,7 +2534,7 @@ class ApiMethods(ABC):
 
     async def answer_inline_query(
         self,
-        inline_query_id: str,
+        inline_query_id: InlineQueryId,
         results: Sequence[InlineQueryResult],
         cache_time: int | None = None,
         is_personal: bool | None = None,
